==> react-native-bugsee-5.4.1.tgz: package/src/common/componentState.js <==
import { NativeModules } from 'react-native';
import { addNativeEventListener } from './nativeEvents';
import { isNil, isFunction, wrapAsyncTimeout } from './utils';
const NativeBridge = NativeModules.Bugsee;
export class ComponentState {
    $handler;
    $handlerSet = false;
    $state;
    $initialized = false;
    $options;
    enabled = false;
    launched = false;
    constructor(stateInit) {
        this.$state = Object.assign({}, stateInit);
        if (!isNil(stateInit.enabled)) {
            this.enabled = !!stateInit.enabled;
        }
    }
    checkControlOption() {
        const { controlOptionName } = this.$state;
        const options = this.$options;
        if (controlOptionName && options && !isNil(options[controlOptionName])) {
            this.enabled = !!options[controlOptionName];
        }
    }
    setHandler(value) {
        if (isFunction(value) || isNil(value)) {
            this.$handler = wrapAsyncTimeout(value, this.$state.handlerTimeout);
            if (this.$state.flagName) {
                NativeBridge.setFlag(this.$state.flagName, !!value);
            }
            if (value &&
                !this.$handlerSet &&
                this.$state.nativeEventName &&
                this.$state.nativeEventHandler) {
                this.$handlerSet = true;
                addNativeEventListener(this.$state.nativeEventName, this.$state.nativeEventHandler);
            }
        }
    }
    async executeHandler(arg) {
        if (this.enabled && this.$handler) {
            return this.$handler(arg);
        }
        return Promise.resolve(undefined);
    }
    get handlerSet() {
        return !isNil(this.$handler);
    }
    get options() {
        return this.$options;
    }
    initialize(options) {
        if (!this.$initialized) {
            this.$initialized = true;
            this.$options = options;
            this.checkControlOption();
            this.$state.initCallback?.(this);
        }
    }
    setOptions(options) {
        this.$options = options;
        this.checkControlOption();
    }
    executeDefaultAction(e, auxData) {
        this.$state.defaultActionCallback?.(e, auxData);
    }
}

==> react-native-bugsee-5.5.2.tgz: package/src/common/componentState.js <==
import { addNativeEventListener } from './nativeEvents';
import { isNil, isFunction, wrapAsyncTimeout } from './utils';
import { getRNBugseeModule } from '../utils/bridge';
const NativeBridge = getRNBugseeModule();
export class ComponentState {
    $handler;
    $handlerSet = false;
    $state;
    $initialized = false;
    $options;
    enabled = false;
    launched = false;
    constructor(stateInit) {
        this.$state = Object.assign({}, stateInit);
        if (!isNil(stateInit.enabled)) {
            this.enabled = !!stateInit.enabled;
        }
    }
    checkControlOption() {
        const { controlOptionName } = this.$state;
        const options = this.$options;
        if (controlOptionName && options && !isNil(options[controlOptionName])) {
            this.enabled = !!options[controlOptionName];
        }
    }
    setHandler(value) {
        if (isFunction(value) || isNil(value)) {
            this.$handler = wrapAsyncTimeout(value, this.$state.handlerTimeout);
            if (this.$state.flagName) {
                NativeBridge?.setFlag(this.$state.flagName, !!value);
            }
            if (value &&
                !this.$handlerSet &&
                this.$state.nativeEventName &&
                this.$state.nativeEventHandler) {
                this.$handlerSet = true;
                addNativeEventListener(this.$state.nativeEventName, this.$state.nativeEventHandler);
            }
        }
    }
    async executeHandler(arg) {
        if (this.enabled && this.$handler) {
            return this.$handler(arg);
        }
        return Promise.resolve(undefined);
    }
    get handlerSet() {
        return !isNil(this.$handler);
    }
    get options() {
        return this.$options;
    }
    initialize(options) {
        if (!this.$initialized) {
            this.$initialized = true;
            this.$options = options;
            this.checkControlOption();
            this.$state.initCallback?.(this);
        }
    }
    setOptions(options) {
        this.$options = options;
        this.checkControlOption();
    }
    executeDefaultAction(e, auxData) {
        this.$state.defaultActionCallback?.(e, auxData);
    }
}
